opendvp.plotting package
========================

Submodules
----------

opendvp.plotting.dynamic\_histogram module
------------------------------------------

.. automodule:: opendvp.plotting.dynamic_histogram
   :members:
   :show-inheritance:
   :undoc-members:

opendvp.plotting.export\_figure module
--------------------------------------

.. automodule:: opendvp.plotting.export_figure
   :members:
   :show-inheritance:
   :undoc-members:

opendvp.plotting.stacked\_barplot module
----------------------------------------

.. automodule:: opendvp.plotting.stacked_barplot
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: opendvp.plotting
   :members:
   :show-inheritance:
   :undoc-members:
